@@ -30,7 +30,9 @@ static int opt_bytes = 0;
 static int opt_list = 0;
 static int opt_size = 800;
 static int opt_gradient = 0;
+static char *opt_footer = NULL;
 static double opt_fuzz = 0.7;
+static char *opt_header = NULL;
 static int opt_levels = 4;
 static char *opt_palette = NULL;
 static int opt_tooltip = 0;
@@ -52,10 +54,29 @@ static void print_html(const char *s)
 	}
 }
 
+static int isrfc1738(const char c)
+{
+	switch (c) {
+		case '$':
+		case '-':
+		case '_':
+		case '.':
+		case '+':
+		case '!':
+		case '*':
+		case '(':
+		case ')':
+			return 1;
+		default:
+			return 0;
+	}
+	return 0;
+}
+
 static void print_cgi(const char *s)
 {
 	while(*s) {
-		if(*s == '/' || isalnum(*s)) {
+		if(*s == '/' || isrfc1738(*s) || isalnum(*s)) {
 			putchar(*s);
 		} else {
 			printf("%%%02x", *(uint8_t *)s);
@@ -188,11 +209,13 @@ static void print_script(const char *path)
 		"    var tt = document.getElementById('tooltip');\n"
 		"    var timer;\n"
 		"    img.onmousedown = function(e) {\n"
+		"      if(e.button == 0) {\n"
 		"        var x = e.clientX - rect.left;\n"
 		"        var y = e.clientY - rect.top;\n"
 		"        window.location = '?x=' + x + '&y=' + y + '&path=");
 	print_html(path);
 	printf( "';\n"
+		"      }\n"
 		"    }\n");
 
 	if(opt_tooltip) {
@@ -225,6 +248,23 @@ static void print_script(const char *path)
 }
 
 
+static void include_file(const char *fname)
+{
+	FILE *f = fopen(fname, "rb");
+	if(f) {
+		printf("<!-- start include -->\n");
+		for(;;) {
+			char buf[4096];
+			size_t n = fread(buf, 1, sizeof(buf), f);
+			if(n == 0) break;
+			fwrite(buf, 1, n, stdout);
+		}
+		printf("<!-- end include -->\n");
+		fclose(f);
+	}
+}
+
+
 static void do_index(duc *duc, duc_graph *graph, duc_dir *dir)
 {
 
@@ -272,11 +312,12 @@ static void do_index(duc *duc, duc_graph *graph, duc_dir *dir)
 		print_script(path);
 	}
 
-	printf(
-		"</head>\n"
-		"<div id=main>\n"
-	);
+	printf("</head>\n");
+	printf("<body>\n");
 
+	include_file(opt_header);
+
+	printf("<div id=main>\n");
 	printf("<div id=index>");
 	printf(" <table>\n");
 	printf("  <tr>\n");
@@ -342,7 +383,7 @@ static void do_index(duc *duc, duc_graph *graph, duc_dir *dir)
 
 		struct duc_dirent *e;
 		int n = 0;
-		while((n++ < 40) && (e = duc_dir_read(dir, st)) != NULL) {
+		while((n++ < 40) && (e = duc_dir_read(dir, st, DUC_SORT_SIZE)) != NULL) {
 			char siz[32];
 			duc_human_size(&e->size, st, opt_bytes, siz, sizeof siz);
 			printf("  <tr><td class=name>");
@@ -374,6 +415,13 @@ static void do_index(duc *duc, duc_graph *graph, duc_dir *dir)
 		printf("<div id=\"tooltip\"></div>\n");
 	}
 
+	printf("</div>\n");
+
+	include_file(opt_footer);
+
+	printf("</body>\n");
+	printf("</html>\n");
+
 	fflush(stdout);
 }
 
@@ -462,6 +510,7 @@ static int cgi_main(duc *duc, int argc, char **argv)
 		if(c == 'r') palette = DUC_GRAPH_PALETTE_RAINBOW;
 		if(c == 'g') palette = DUC_GRAPH_PALETTE_GREYSCALE;
 		if(c == 'm') palette = DUC_GRAPH_PALETTE_MONOCHROME;
+		if(c == 'c') palette = DUC_GRAPH_PALETTE_CLASSIC;
 	}
 
 	duc_size_type st = opt_count ? DUC_SIZE_TYPE_COUNT : 
@@ -492,16 +541,19 @@ static struct ducrc_option options[] = {
 	{ &opt_count,     "count",      0,  DUCRC_TYPE_BOOL,   "show number of files instead of file size" },
 	{ &opt_css_url,   "css-url",    0,  DUCRC_TYPE_STRING, "url of CSS style sheet to use instead of default CSS" },
 	{ &opt_database,  "database",  'd', DUCRC_TYPE_STRING, "select database file to use [~/.duc.db]" },
+	{ &opt_footer,    "footer",     0,  DUCRC_TYPE_STRING, "select HTML file to include as footer" },
 	{ &opt_fuzz,      "fuzz",       0,  DUCRC_TYPE_DOUBLE, "use radius fuzz factor when drawing graph [0.7]" },
 	{ &opt_gradient,  "gradient",   0,  DUCRC_TYPE_BOOL,   "draw graph with color gradient" },
+	{ &opt_header,    "header",     0,  DUCRC_TYPE_STRING, "select HTML file to include as header" },
 	{ &opt_levels,    "levels",    'l', DUCRC_TYPE_INT,    "draw up to ARG levels deep [4]" },
 	{ &opt_list,      "list",       0,  DUCRC_TYPE_BOOL,   "generate table with file list" },
-	{ &opt_palette,   "palette",    0,  DUCRC_TYPE_STRING, "select palette <size|rainbow|greyscale|monochrome>" },
+	{ &opt_palette,   "palette",    0,  DUCRC_TYPE_STRING, "select palette",
+		"available palettes are: size, rainbow, greyscale, monochrome, classic" },
 	{ &opt_ring_gap,  "ring-gap",   0,  DUCRC_TYPE_INT,    "leave a gap of VAL pixels between rings" },
 	{ &opt_size,      "size",      's', DUCRC_TYPE_INT,    "image size [800]" },
 	{ &opt_tooltip,   "tooltip",    0,  DUCRC_TYPE_BOOL,   "enable tooltip when hovering over the graph",
 		"enabling the tooltip will cause an asynchronous HTTP request every time the mouse is moved and "
-		"can greatly increas the HTTP traffic to the web server" },
+		"can greatly increase the HTTP traffic to the web server" },
 	{ NULL }
 };
 
