@@ -107,7 +107,13 @@ static int index_main(duc *duc, int argc, char **argv)
 					siz_actual,
 					dur);
 		} else {
-			duc_log(duc, DUC_LOG_WRN, "An error occured while indexing: %s", duc_strerror(duc));
+			duc_log(duc, DUC_LOG_WRN, "An error occurred while indexing: %s", duc_strerror(duc));
+		}
+
+		/* Prevent final output of progress_cb() from being overwritten with the shell's prompt */
+		if (opt_progress) {
+			fputc ('\n', stdout);
+			fflush (stdout);
 		}
 
 		duc_index_report_free(report);
