@@ -46,6 +46,7 @@ static int opt_count = 0;
 static int opt_bytes = 0;
 static int opt_graph = 1;
 static int opt_nocolor = 0;
+static int opt_name_sort = 0;
 static char *opt_database = NULL;
 
 
@@ -87,13 +88,21 @@ static duc_dir *do_dir(duc_dir *dir, int depth)
 		duc_dir_seek(dir, 0);
 
 		off_t size_max = 1;
+		int dir_count = 0;
+		int file_count = 0;
 		struct duc_dirent *e;
-		while( (e = duc_dir_read(dir, st)) != NULL) {
+		duc_sort sort = opt_name_sort ? DUC_SORT_NAME : DUC_SORT_SIZE;
+		while( (e = duc_dir_read(dir, st, sort)) != NULL) {
+			if(e->type == DUC_FILE_TYPE_DIR) {
+				dir_count ++;
+			} else {
+				file_count ++;
+			}
 			off_t size = duc_get_size(&e->size, st);
 			if(size > size_max) size_max = size;
 		}
 
-		int count = duc_dir_get_count(dir);
+		int count = dir_count + file_count;
 		int pgsize = rows - 2;
 		
 		/* Check boundaries */
@@ -119,12 +128,13 @@ static duc_dir *do_dir(duc_dir *dir, int depth)
 
 		struct duc_size size;
 		duc_dir_get_size(dir, &size);
-		char siz[32], cnt[32];
+		char siz[32], fcnt[32], dcnt[32];
 		duc_human_size(&size, st, opt_bytes, siz, sizeof siz);
-		duc_human_number(count, opt_bytes, cnt, sizeof cnt);
+		duc_human_number(file_count, opt_bytes, fcnt, sizeof fcnt);
+		duc_human_number(dir_count, opt_bytes, dcnt, sizeof dcnt);
 		attrset(attr_bar);
 		mvhline(rows-1, 0, ' ', cols);
-		mvprintw(rows-1, 0, " Total %sB in %s files/directories (", siz, cnt);
+		mvprintw(rows-1, 0, " Total %sB in %s files and %s directories (", siz, fcnt, dcnt);
 		switch(st) {
 			case DUC_SIZE_TYPE_APPARENT: printw("apparent size"); break;
 			case DUC_SIZE_TYPE_ACTUAL: printw("actual size"); break;
@@ -142,7 +152,7 @@ static duc_dir *do_dir(duc_dir *dir, int depth)
 
 		for(i=top; i<top + pgsize; i++) {
 			
-			struct duc_dirent *e = duc_dir_read(dir, st);
+			struct duc_dirent *e = duc_dir_read(dir, st, sort);
 
 			attrset(cur == i ? attr_cursor : 0);
 			mvhline(y, 0, ' ', cols);
@@ -210,12 +220,17 @@ static duc_dir *do_dir(duc_dir *dir, int depth)
 			case 4: cur += pgsize/2; break;
 			case KEY_NPAGE: cur += pgsize; break;
 			case KEY_RESIZE: getmaxyx(stdscr, rows, cols); break;
+			case '0': cur = 0; break;
+			case KEY_HOME: cur = 0; break;
+			case '$': cur = count-1; break;
+			case KEY_END: cur = count-1; break;
 			case 'a': opt_apparent ^= 1; break;
 			case 'b': opt_bytes ^= 1; break;
 			case 'C': opt_nocolor ^= 1; break;
 			case 'c': opt_count ^= 1; break;
 			case 'g': opt_graph ^= 1; break;
 			case 'h': help(); break;
+			case 'n': opt_name_sort ^= 1; break;
 
 			case 27:
 			case 'q': 
@@ -238,8 +253,8 @@ static duc_dir *do_dir(duc_dir *dir, int depth)
 			case '\r':
 			case '\n': 
 				  duc_dir_seek(dir, cur);
-				  struct duc_dirent *e = duc_dir_read(dir, st);
-				  if(e->type == DUC_FILE_TYPE_DIR) {
+				  struct duc_dirent *e = duc_dir_read(dir, st, sort);
+				  if(e && e->type == DUC_FILE_TYPE_DIR) {
 					dir2 = duc_dir_openent(dir, e);
 					if(dir2) {
 						do_dir(dir2, depth + 1);
@@ -310,8 +325,9 @@ static struct ducrc_option options[] = {
 	{ &opt_apparent,  "apparent",  'a', DUCRC_TYPE_BOOL,   "show apparent instead of actual file size" },
 	{ &opt_bytes,     "bytes",     'b', DUCRC_TYPE_BOOL,   "show file size in exact number of bytes" },
 	{ &opt_count,     "count",      0,  DUCRC_TYPE_BOOL,   "show number of files instead of file size" },
-	{ &opt_nocolor,   "no-color",   0 , DUCRC_TYPE_BOOL,   "do not use colors on terminal output" },
 	{ &opt_database,  "database",  'd', DUCRC_TYPE_STRING, "select database file to use [~/.duc.db]" },
+	{ &opt_name_sort, "name-sort", 'n', DUCRC_TYPE_BOOL,   "sort output by name instead of by size" },
+	{ &opt_nocolor,   "no-color",   0 , DUCRC_TYPE_BOOL,   "do not use colors on terminal output" },
 	{ NULL }
 };
 
@@ -323,7 +339,7 @@ struct cmd cmd_ui = {
 	.main = ui_main,
 	.options = options,
 	.descr_long = 
-		"The 'gui' subcommand queries the duc database and runs an interactive ncurses\n"
+		"The 'ui' subcommand queries the duc database and runs an interactive ncurses\n"
 		"utility for exploring the disk usage of the given path. If no path is given the\n"
 		"current working directory is explored.\n"
 		"\n"
@@ -331,12 +347,15 @@ struct cmd cmd_ui = {
 		"\n"
 		"    up, pgup, j:     move cursor up\n"
 		"    down, pgdn, k:   move cursor down\n"
+		"    home, 0:         move cursor to top\n"
+		"    end, $:          move cursor to bottom\n"
 		"    left, backspace: go up to parent directory (..)\n"
 		"    right, enter:    descent into selected directory\n"
 		"    a:               toggle between actual and apparent disk usage\n"
 		"    b:               toggle between exact and abbreviated sizes\n"
 		"    c:               Toggle between file size and file count\n"
 		"    h:               show help. press 'q' to return to the main screen\n"
+		"    n:               toggle sort order between 'size' and 'name'\n"
 		"    q, escape:       quit\n"
 
 };
