@@ -86,7 +86,7 @@ static void br_svg_draw_tooltip(duc_graph *g, double x, double y, char *text)
 }
 
 
-static void br_svg_draw_section(duc_graph *g, double a1, double a2, double r1, double r2, double H, double S, double V, double line)
+static void br_svg_draw_section(duc_graph *g, double a1, double a2, double r1, double r2, double H, double S, double V, double L)
 {
 	struct svg_backend_data *bd = g->backend_data;
 	FILE *f = bd->fout;
